Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to Amazon Simple Workflow Service.
Keywords: IAM,AWS Identity and Access Management,IAM user,user,IAM group,group,IAM role,role,permission policy,trust policy,policy,access key,password

Actions, Resources, and Condition Keys for Amazon Simple Workflow Service - AWS Identity and Access Management

# Actions, Resources, and Condition Keys for Amazon Simple Workflow Service

Amazon Simple Workflow Service (service prefix: `swf` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

Topics

- Actions Defined by Amazon Simple Workflow Service
- Resource Types Defined by Amazon Simple Workflow Service
- Condition Keys for Amazon Simple Workflow Service

## Actions Defined by Amazon Simple Workflow Service

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource Types column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see The Actions Table .

Actions | Description | Access Level | Resource Types (*required) | Condition Keys | Dependent Actions
--- | --- | --- | --- | --- | ---
CancelTimer | Description for CancelTimer | Write | domain* |  |
CancelWorkflowExecution | Description for CancelWorkflowExecution | Write | domain* |  |
CompleteWorkflowExecution | Description for CompleteWorkflowExecution | Write | domain* |  |
ContinueAsNewWorkflowExecution | Description for ContinueAsNewWorkflowExecution | Write | domain* |  |
CountClosedWorkflowExecutions | Returns the number of closed workflow executions within the given domain that meet the specified filtering criteria. | Read | domain* |  |
| swf:tagFilter.tag swf:typeFilter.name swf:typeFilter.version |
CountOpenWorkflowExecutions | Returns the number of open workflow executions within the given domain that meet the specified filtering criteria. | Read | domain* |  |
| swf:tagFilter.tag swf:typeFilter.name swf:typeFilter.version |
CountPendingActivityTasks | Returns the estimated number of activity tasks in the specified task list. | Read | domain* |  |
| swf:taskList.name |
CountPendingDecisionTasks | Returns the estimated number of decision tasks in the specified task list. | Read | domain* |  |
| swf:taskList.name |
DeprecateActivityType | Deprecates the specified activity type. | Write | domain* |  |
| swf:activityType.name swf:activityType.version |
DeprecateDomain | Deprecates the specified domain. | Write | domain* |  |
DeprecateWorkflowType | Deprecates the specified workflow type. | Write | domain* |  |
| swf:workflowType.name swf:workflowType.version |
DescribeActivityType | Returns information about the specified activity type. | Read | domain* |  |
| swf:activityType.name swf:activityType.version |
DescribeDomain | Returns information about the specified domain, including description and status. | Read | domain* |  |
DescribeWorkflowExecution | Returns information about the specified workflow execution including its type and some statistics. | Read | domain* |  |
DescribeWorkflowType | Returns information about the specified workflow type. | Read | domain* |  |
| swf:workflowType.name swf:workflowType.version |
FailWorkflowExecution | Description for FailWorkflowExecution | Write | domain* |  |
GetWorkflowExecutionHistory | Returns the history of the specified workflow execution. | Read | domain* |  |
ListActivityTypes | Returns information about all activities registered in the specified domain that match the specified name and registration status. | List | domain* |  |
ListClosedWorkflowExecutions | Returns a list of closed workflow executions in the specified domain that meet the filtering criteria. | List | domain* |  |
| swf:tagFilter.tag swf:typeFilter.name swf:typeFilter.version |
ListDomains | Returns the list of domains registered in the account. | List |  |  |
ListOpenWorkflowExecutions | Returns a list of open workflow executions in the specified domain that meet the filtering criteria. | List | domain* |  |
| swf:tagFilter.tag swf:typeFilter.name swf:typeFilter.version |
ListTagsForResource | This action lists tags for an AWS SWF resource. | List | domain |  |
ListWorkflowTypes | Returns information about workflow types in the specified domain. | List | domain* |  |
PollForActivityTask | Used by workers to get an ActivityTask from the specified activity taskList. | Write | domain* |  |
| swf:taskList.name |
PollForDecisionTask | Used by deciders to get a DecisionTask from the specified decision taskList. | Write | domain* |  |
| swf:taskList.name |
RecordActivityTaskHeartbeat | Used by activity workers to report to the service that the ActivityTask represented by the specified taskToken is still making progress. | Write | domain* |  |
RecordMarker | Description for RecordMarker | Write | domain* |  |
RegisterActivityType | Registers a new activity type along with its configuration settings in the specified domain. | Write | domain* |  |
| swf:defaultTaskList.name swf:name swf:version |
RegisterDomain | Registers a new domain. | Write |  | aws:TagKeys aws:RequestTag/${TagKey} |
RegisterWorkflowType | Registers a new workflow type and its configuration settings in the specified domain. | Write | domain* |  |
| swf:defaultTaskList.name swf:name swf:version |
RequestCancelActivityTask | Description for RequestCancelActivityTask | Write | domain* |  |
RequestCancelExternalWorkflowExecution | Description for RequestCancelExternalWorkflowExecution | Write | domain* |  |
RequestCancelWorkflowExecution | Records a WorkflowExecutionCancelRequested event in the currently running workflow execution identified by the given domain, workflowId, and runId. | Write | domain* |  |
RespondActivityTaskCanceled | Used by workers to tell the service that the ActivityTask identified by the taskToken was successfully canceled. | Write | domain* |  |
RespondActivityTaskCompleted | Used by workers to tell the service that the ActivityTask identified by the taskToken completed successfully with a result (if provided). | Write | domain* |  |
| swf:activityType.name swf:activityType.version swf:tagList.member.0 swf:tagList.member.1 swf:tagList.member.2 swf:tagList.member.3 swf:tagList.member.4 swf:taskList.name swf:workflowType.name swf:workflowType.version |
RespondActivityTaskFailed | Used by workers to tell the service that the ActivityTask identified by the taskToken has failed with reason (if specified). | Write | domain* |  |
RespondDecisionTaskCompleted | Used by deciders to tell the service that the DecisionTask identified by the taskToken has successfully completed. | Write | domain* |  |
ScheduleActivityTask | Description for ScheduleActivityTask | Write | domain* |  |
SignalExternalWorkflowExecution | Description for SignalExternalWorkflowExecution | Write | domain* |  |
SignalWorkflowExecution | Records a WorkflowExecutionSignaled event in the workflow execution history and creates a decision task for the workflow execution identified by the given domain, workflowId and runId. | Write | domain* |  |
StartChildWorkflowExecution | Description for StartChildWorkflowExecution | Write | domain* |  |
StartTimer | Description for StartTimer | Write | domain* |  |
StartWorkflowExecution | Starts an execution of the workflow type in the specified domain using the provided workflowId and input data. | Write | domain* |  |
| swf:tagList.member.0 swf:tagList.member.1 swf:tagList.member.2 swf:tagList.member.3 swf:tagList.member.4 swf:taskList.name swf:workflowType.name swf:workflowType.version |
TagResource | This action tags an AWS SWF resource. | Tagging | domain |  |
| aws:TagKeys aws:RequestTag/${TagKey} |
TerminateWorkflowExecution | Records a WorkflowExecutionTerminated event and forces closure of the workflow execution identified by the given domain, runId, and workflowId. | Write | domain* |  |
UntagResource | This action removes a tag from an AWS SWF resource. | Tagging | domain |  |
| aws:TagKeys |

## Resource Types Defined by Amazon Simple Workflow Service

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the table. For details about the columns in the following table, see The Resource Types Table .

Resource Types | ARN | Condition Keys
--- | --- | ---
domain | `arn:$ { Partition}:swf::$ { Account}:domain/$ { DomainName}` | aws:ResourceTag/${TagKey}

## Condition Keys for Amazon Simple Workflow Service

Amazon Simple Workflow Service defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see The Condition Keys Table .

To view the global condition keys that are available to all services, see Available Global Condition Keys in the IAM Policy Reference .

Condition Keys | Description | Type
--- | --- | ---
aws:RequestTag/${TagKey} | Tag for request. | String
aws:ResourceTag/${TagKey} | Tag for resource. | String
aws:TagKeys | Tag for key. | String
swf:activityType.name | Constrains the policy statement to only an activity type of the specified name. | String
swf:activityType.version | Contstrains the policy statement to only an activity type of the specified version. | String
swf:defaultTaskList.name | Constrains the policy statement to only requests that specify a matching defaultTaskList name. | String
swf:name | Constrains the policy statement to only activities or workflows with the specified name. | String
swf:tagFilter.tag | Constrains the policy statement to only requests that specify a matching tagFilter.tag value. | String
swf:tagList.member.0 | Constrains the policy statement to only requests that contain the specified tag. | String
swf:tagList.member.1 | Constrains the policy statement to only requests that contain the specified tag. | String
swf:tagList.member.2 | Constrains the policy statement to only requests that contain the specified tag. | String
swf:tagList.member.3 | Constrains the policy statement to only requests that contain the specified tag. | String
swf:tagList.member.4 | Constrains the policy statement to only requests that contain the specified tag. | String
swf:taskList.name | Constrains the policy statement to only requests that specify a tasklist with the specified name. | String
swf:typeFilter.name | Constrains the policy statement to only requests that specify a type filter with the specified name. | String
swf:typeFilter.version | Constrains the policy statement to only requests that specify a type filter with the specified version. | String
swf:version | Constrains the policy statement to only activities or workflows with the specified version. | String
swf:workflowType.name | Constrains the policy statement to only a workflow of the specified type. | String
swf:workflowType.name | Constrains the policy statement to only requests that specify a workflow type of the specified name. | String
swf:workflowType.version | Constrains the policy statement to only requests that specify a workflow type of the specified version. | String

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.